@import url("https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css");
@import "boostrap-5.1.3/_functions.scss";
@import "boostrap-5.1.3/_variables.scss";
@import "boostrap-5.1.3/_breakpoints.scss";
@import '_globals.scss';
@import '_mixins.scss';
@import '_ribbon.scss';
@import '_page.scss';
