@import url("https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css");
.bg-ltgray {
  background: #c8c8c8;
}

.text-ltgray {
  color: #c8c8c8 !important;
}

.bg-ltgray-lt {
  color: #c8c8c8 !important;
  background: rgba(200, 200, 200, 0.1) !important;
}

.border-ltgray {
  border-color: #c8c8c8 !important;
}

.bg-gray {
  background: #aaa99f;
}

.text-gray {
  color: #aaa99f !important;
}

.bg-gray-lt {
  color: #aaa99f !important;
  background: rgba(170, 169, 159, 0.1) !important;
}

.border-gray {
  border-color: #aaa99f !important;
}

.bg-medgray {
  background: #76777b;
}

.text-medgray {
  color: #76777b !important;
}

.bg-medgray-lt {
  color: #76777b !important;
  background: rgba(118, 119, 123, 0.1) !important;
}

.border-medgray {
  border-color: #76777b !important;
}

.bg-black-text {
  background: #333333;
}

.text-black-text {
  color: #333333 !important;
}

.bg-black-text-lt {
  color: #333333 !important;
  background: rgba(51, 51, 51, 0.1) !important;
}

.border-black-text {
  border-color: #333333 !important;
}

.bg-ribbon {
  background: #eaeaea;
}

.text-ribbon {
  color: #eaeaea !important;
}

.bg-ribbon-lt {
  color: #eaeaea !important;
  background: rgba(234, 234, 234, 0.1) !important;
}

.border-ribbon {
  border-color: #eaeaea !important;
}

.bg-ribbon_text {
  background: #CCCCCC;
}

.text-ribbon_text {
  color: #CCCCCC !important;
}

.bg-ribbon_text-lt {
  color: #CCCCCC !important;
  background: rgba(204, 204, 204, 0.1) !important;
}

.border-ribbon_text {
  border-color: #CCCCCC !important;
}

.bg-blue {
  background: #0d6efd;
}

.text-blue {
  color: #0d6efd !important;
}

.bg-blue-lt {
  color: #0d6efd !important;
  background: rgba(13, 110, 253, 0.1) !important;
}

.border-blue {
  border-color: #0d6efd !important;
}

.bg-azure {
  background: #4299e1;
}

.text-azure {
  color: #4299e1 !important;
}

.bg-azure-lt {
  color: #4299e1 !important;
  background: rgba(66, 153, 225, 0.1) !important;
}

.border-azure {
  border-color: #4299e1 !important;
}

.bg-indigo {
  background: #6610f2;
}

.text-indigo {
  color: #6610f2 !important;
}

.bg-indigo-lt {
  color: #6610f2 !important;
  background: rgba(102, 16, 242, 0.1) !important;
}

.border-indigo {
  border-color: #6610f2 !important;
}

.bg-pink {
  background: #d63384;
}

.text-pink {
  color: #d63384 !important;
}

.bg-pink-lt {
  color: #d63384 !important;
  background: rgba(214, 51, 132, 0.1) !important;
}

.border-pink {
  border-color: #d63384 !important;
}

.bg-red {
  background: #dc3545;
}

.text-red {
  color: #dc3545 !important;
}

.bg-red-lt {
  color: #dc3545 !important;
  background: rgba(220, 53, 69, 0.1) !important;
}

.border-red {
  border-color: #dc3545 !important;
}

.bg-orange {
  background: #fd7e14;
}

.text-orange {
  color: #fd7e14 !important;
}

.bg-orange-lt {
  color: #fd7e14 !important;
  background: rgba(253, 126, 20, 0.1) !important;
}

.border-orange {
  border-color: #fd7e14 !important;
}

.bg-yellow {
  background: #ffc107;
}

.text-yellow {
  color: #ffc107 !important;
}

.bg-yellow-lt {
  color: #ffc107 !important;
  background: rgba(255, 193, 7, 0.1) !important;
}

.border-yellow {
  border-color: #ffc107 !important;
}

.bg-lime {
  background: #74b816;
}

.text-lime {
  color: #74b816 !important;
}

.bg-lime-lt {
  color: #74b816 !important;
  background: rgba(116, 184, 22, 0.1) !important;
}

.border-lime {
  border-color: #74b816 !important;
}

.bg-green {
  background: #198754;
}

.text-green {
  color: #198754 !important;
}

.bg-green-lt {
  color: #198754 !important;
  background: rgba(25, 135, 84, 0.1) !important;
}

.border-green {
  border-color: #198754 !important;
}

.bg-teal {
  background: #20c997;
}

.text-teal {
  color: #20c997 !important;
}

.bg-teal-lt {
  color: #20c997 !important;
  background: rgba(32, 201, 151, 0.1) !important;
}

.border-teal {
  border-color: #20c997 !important;
}

.bg-cyan {
  background: #0dcaf0;
}

.text-cyan {
  color: #0dcaf0 !important;
}

.bg-cyan-lt {
  color: #0dcaf0 !important;
  background: rgba(13, 202, 240, 0.1) !important;
}

.border-cyan {
  border-color: #0dcaf0 !important;
}

:root {
  font-size: 18px !important;
}
:root .form-control-plaintext {
  padding: 0.4375rem 0.75rem;
}
:root .widget-list__sidebar .h2,
:root .widget-list__main .h2 {
  margin-bottom: 0;
}
:root .widget-index__item {
  font-size: 1rem;
}
:root .bg-light {
  color: var(--tblr-body-color) !important;
}

@media only screen and (min-width: 1200px) {
  .navbar-vertical .navbar-brand {
    justify-content: start !important;
    margin-bottom: 1rem;
  }
}
.messages__item:first-child {
  margin-top: 1rem;
}

.submenu .nav-link.active {
  background-color: rgba(245, 159, 0, 0.3);
  border-radius: 20px;
}

pre {
    background-color: #f8f8f8;
    color: black;
    border: 1px solid #CCCCCC;
}
/* ===================================================================
   Use these in your CSS via the SCSS mixin syntax.  Example:

   @import "_mixins.scss";

   .my_title {
     @include serif-title();
   }
=================================================================== */
/*
  Turn a <ul> or <ol> into a set of all caps,
  white links, horizontally oriented.  Usage:

  .my-nav {
    @include all-caps-horizontal-links();
  }

*/
/*
  Center something in the browser window, and make it
  be @responsive_grid_w wide.  Usage:

  .my-div {
    @include page-width-centered();
  }
*/
/* ======================================
   The grey ribbon at the top of the page
   ====================================== */
.ribbon_bar {
  border-bottom: 1px solid #ccc;
  background: white;
  background: linear-gradient(180deg, white 0%, #eaeaea 80%, #e0e0e0 100%);
  position: relative;
  z-index: 501;
}
.ribbon_bar__content {
  min-height: 38px;
}
.ribbon_bar__content__links {
  margin: 0;
  font-size: 0.8em;
  font-size: 0.78571429em;
}
.ribbon_bar__content__links a, .ribbon_bar__content__links a:visited {
  color: #ffffff !important;
  text-transform: uppercase;
  font-weight: bold;
}
.ribbon_bar__content__links li {
  display: inline-block;
  padding-left: 1.25em;
}
.ribbon_bar__content__links li:first-child {
  padding-left: 0;
}
.ribbon_bar__content__links a {
  margin-left: 10px;
}
.ribbon_bar__content__login {
  color: #333333;
  font-size: 1.3rem;
}
.ribbon_bar__content__username {
  display: block;
  color: #333333;
}
.ribbon_bar__content__breadcrumbs .breadcrumb-item + .breadcrumb-item::before {
  color: #333333;
}
.ribbon_bar__content__breadcrumbs .breadcrumb-item.active a {
  pointer-events: auto !important;
  text-decoration: none;
}
.ribbon_bar__content__breadcrumbs .breadcrumb-item:not(.active) {
  font-weight: bold;
}

/* ==================
   Page
   ================== */
.page {
  display: flex;
}
.page__content {
  flex: 1 0 auto;
  margin-top: 2rem;
  margin-bottom: 2rem;
}

/* ==================
   Page Footer
   ================== */
.footer {
  border-top: 1px solid #ccc;
  background: #f4f4f4;
  font-size: 0.8rem;
}
.footer__content__contact {
  line-height: 1.4;
  color: #333333;
}
.footer__content__contact a, .footer__content__contact a:visited {
  color: #333333;
}
.footer__content__links {
  margin: 0;
  font-size: 0.8em;
}
.footer__content__links a, .footer__content__links a:visited {
  color: #ffffff !important;
  text-transform: uppercase;
  font-weight: bold;
}
.footer__content__links li {
  display: inline-block;
  padding-left: 1.25em;
}
.footer__content__links li:first-child {
  padding-left: 0;
}

/*# sourceMappingURL=theme.css.map */